@@ -2,12 +2,13 @@ package Data::WeightedRoundRobin;
 
 use strict;
 use warnings;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our $DEFAULT_WEIGHT = 100;
 our $BTREE_BORDER = 10;
 
 use Scope::Guard qw(guard);
+use Data::Clone qw(clone);
 
 sub new {
     my ($class, $list, $args) = @_;
@@ -176,7 +177,7 @@ sub next {
 
 sub save {
     my $self = shift;
-    my $orig_rrlist = $self->{rrlist};
+    my $orig_rrlist = clone $self->{rrlist};
     guard { $self->set($orig_rrlist) };
 }
 
@@ -280,7 +281,7 @@ Replace a value. Returned value is 1 or 0, but if error is undef.
 
   use Test::More;
   my $dwr = Data::WeightedRoundRobin->new([qw/foo/, { value => 'bar', weight => 50 }]);
-  is $dwr->replace('baz'), 1, 'replaced bar'; 
+  is $dwr->replace('bar'), 1, 'replaced bar to default weight (50 -> 100)';
   is $dwr->replace('hoge'), 0, 'hoge is not found';
   is $dwr->replace({ value => 'foo', weight => 80 }), 1, 'replaced foo with weight 80';
   is $dwr->replace(), undef, 'error';
